------------------------------
 SYNERGY SERVICE
------------------------------

Synergy is as a new extensible general purpose management OpenStack service.
Its capabilities are implemented by a collection of managers which are specific
and independent pluggable tasks, executed periodically or interactively. The
managers can interact with each other in a loosely coupled way.

* Free software: Apache license
* Documentation: https://indigo-dc.gitbooks.io/synergy-doc/content/
* Source: http://git.openstack.org/cgit/openstack/synergy-service
* Bugs: http://bugs.launchpad.net/synergy-service
